==> jc-1.4.0.tar.gz: java/nio/channels/Pipe.c <==
// public abstract class java.nio.channels.Pipe

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 2951d2f8b8defcbd java_nio_channels_Pipe
// @dep_class 8a9bac808797868c java_nio_channels_Pipe__24SinkChannel
// @dep_class 2a71a1103f7cdc8f java_nio_channels_Pipe__24SourceChannel
// @dep_class 7a7cc23db1b62549 java_nio_channels_spi_SelectorProvider

// header file dependencies
// @dep_header java_io_IOException
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_nio_channels_Pipe
// @dep_header java_nio_channels_Pipe__24SinkChannel
// @dep_header java_nio_channels_Pipe__24SourceChannel
// @dep_header java_nio_channels_spi_SelectorProvider

#include "jc_defs.h"

#include "java/io/IOException.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/nio/channels/Pipe.h"
#include "java/nio/channels/Pipe__24SinkChannel.h"
#include "java/nio/channels/Pipe__24SourceChannel.h"
#include "java/nio/channels/spi/SelectorProvider.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static java.nio.channels.Pipe open() throws java.io.IOException
//

static _jc_linenum _jc_java_nio_channels_Pipe$linenum_table$open$c01270b8d8c80227[];

static const unsigned char _jc_java_nio_channels_Pipe$param_ptypes$open$c01270b8d8c80227[] = { 
_JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_nio_channels_Pipe$exceptions$open$c01270b8d8c80227[] = {
	&_jc_java_io_IOException$type
};

_jc_method _jc_java_nio_channels_Pipe$method_info$open$c01270b8d8c80227 = {
	.name=			"open",
	.signature=		"()Ljava/nio/channels/Pipe;",
	.class=			&_jc_java_nio_channels_Pipe$type,
	.return_type=		&_jc_java_nio_channels_Pipe$type,
	.param_ptypes=		&_jc_java_nio_channels_Pipe$param_ptypes$open$c01270b8d8c80227,
	.signature_hash=	_JC_JLONG(0xc01270b8d8c80227),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_java_nio_channels_Pipe$method$open$c01270b8d8c80227,
	.num_parameters=	0,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_nio_channels_Pipe$exceptions$open$c01270b8d8c80227,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_nio_channels_Pipe$linenum_table$open$c01270b8d8c80227
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_nio_channels_Pipe, open$c01270b8d8c80227);

_jc_java_nio_channels_Pipe$object *
_jc_java_nio_channels_Pipe$method$open$c01270b8d8c80227(_jc_env *const env)
{
	struct _jc_java_nio_channels_spi_SelectorProvider$object *r0;
	struct _jc_java_nio_channels_Pipe$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	_JC_LINE_NUMBER(109);				// 0
	r0 = _JC_INVOKE_STATIC(env, java_nio_channels_spi_SelectorProvider, provider$f1e7ffe0eaeee1b8, 0);
	r1 = _JC_INVOKE_VIRTUAL(env, java_nio_channels_spi_SelectorProvider, openPipe$a14c1306bc23b331, r0);
	return r1;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>()
//

static _jc_linenum _jc_java_nio_channels_Pipe$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_nio_channels_Pipe$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_nio_channels_Pipe$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_nio_channels_Pipe$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_nio_channels_Pipe$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_java_nio_channels_Pipe$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_nio_channels_Pipe$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_nio_channels_Pipe, _init$52f4ad9f2989aeee);

void
_jc_java_nio_channels_Pipe$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_nio_channels_Pipe$object *this)
{
	struct _jc_java_nio_channels_Pipe$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(100);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract java.nio.channels.Pipe$SinkChannel sink()
//

static const unsigned char _jc_java_nio_channels_Pipe$param_ptypes$sink$a72af214bdd8aa6e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_nio_channels_Pipe$method_info$sink$a72af214bdd8aa6e = {
	.name=			"sink",
	.signature=		"()Ljava/nio/channels/Pipe$SinkChannel;",
	.class=			&_jc_java_nio_channels_Pipe$type,
	.return_type=		&_jc_java_nio_channels_Pipe__24SinkChannel$type,
	.param_ptypes=		&_jc_java_nio_channels_Pipe$param_ptypes$sink$a72af214bdd8aa6e,
	.signature_hash=	_JC_JLONG(0xa72af214bdd8aa6e),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_nio_channels_Pipe$method$sink$a72af214bdd8aa6e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_nio_channels_Pipe$vtable, java_nio_channels_Pipe.sink$a72af214bdd8aa6e) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_nio_channels_Pipe__24SinkChannel$object *
_jc_java_nio_channels_Pipe$method$sink$a72af214bdd8aa6e(_jc_env *const env, _jc_java_nio_channels_Pipe$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_nio_channels_Pipe$method_info$sink$a72af214bdd8aa6e);
}

//
// public abstract java.nio.channels.Pipe$SourceChannel source()
//

static const unsigned char _jc_java_nio_channels_Pipe$param_ptypes$source$025193fa1d7529c6[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_nio_channels_Pipe$method_info$source$025193fa1d7529c6 = {
	.name=			"source",
	.signature=		"()Ljava/nio/channels/Pipe$SourceChannel;",
	.class=			&_jc_java_nio_channels_Pipe$type,
	.return_type=		&_jc_java_nio_channels_Pipe__24SourceChannel$type,
	.param_ptypes=		&_jc_java_nio_channels_Pipe$param_ptypes$source$025193fa1d7529c6,
	.signature_hash=	_JC_JLONG(0x25193fa1d7529c6),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_nio_channels_Pipe$method$source$025193fa1d7529c6,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_nio_channels_Pipe$vtable, java_nio_channels_Pipe.source$025193fa1d7529c6) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_nio_channels_Pipe__24SourceChannel$object *
_jc_java_nio_channels_Pipe$method$source$025193fa1d7529c6(_jc_env *const env, _jc_java_nio_channels_Pipe$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_nio_channels_Pipe$method_info$source$025193fa1d7529c6);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_nio_channels_Pipe$methods[] = {
	&_jc_java_nio_channels_Pipe$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_nio_channels_Pipe$method_info$open$c01270b8d8c80227,
	&_jc_java_nio_channels_Pipe$method_info$sink$a72af214bdd8aa6e,
	&_jc_java_nio_channels_Pipe$method_info$source$025193fa1d7529c6
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_nio_channels_Pipe$instanceof_hash_bucket_61[] = {
	&_jc_java_nio_channels_Pipe$type,
	_JC_NULL
};
static _jc_type *const _jc_java_nio_channels_Pipe$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_nio_channels_Pipe$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[61]=	_jc_java_nio_channels_Pipe$instanceof_hash_bucket_61,
	[113]=	_jc_java_nio_channels_Pipe$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_nio_channels_Pipe$class_depends[] = {
	{ "java/io/IOException",	_JC_JLONG(0x4e0a56550c69d57c) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/nio/channels/Pipe$SinkChannel",	_JC_JLONG(0x8a9bac808797868c) },
	{ "java/nio/channels/Pipe$SourceChannel",	_JC_JLONG(0x2a71a1103f7cdc8f) },
	{ "java/nio/channels/spi/SelectorProvider",	_JC_JLONG(0x7a7cc23db1b62549) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Inner class list
static _jc_inner_class _jc_java_nio_channels_Pipe$inner_classes[] = {
	{ &_jc_java_nio_channels_Pipe__24SourceChannel$type, _JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_ABSTRACT },
	{ &_jc_java_nio_channels_Pipe__24SinkChannel$type, _JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_ABSTRACT },
};

// Class info
_jc_java_nio_channels_Pipe$vtype _jc_java_nio_channels_Pipe$type = {
    .type= {
	.name=			"java/nio/channels/Pipe",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x2951d2f8b8defcbd),
		.source_file=		"Pipe.java",
		.instance_size=		sizeof(_jc_java_nio_channels_Pipe$refs) + sizeof(_jc_java_nio_channels_Pipe$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_nio_channels_Pipe$methods) / sizeof(*_jc_java_nio_channels_Pipe$methods),
		.methods=		_jc_java_nio_channels_Pipe$methods,
		.instanceof_hash_table=	_jc_java_nio_channels_Pipe$instanceof_hash_table,
		.num_inner_classes=	2,
		.inner_classes=		_jc_java_nio_channels_Pipe$inner_classes,
		.num_class_depends=		sizeof(_jc_java_nio_channels_Pipe$class_depends) / sizeof(*_jc_java_nio_channels_Pipe$class_depends),
		.class_depends=		_jc_java_nio_channels_Pipe$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_nio_channels_Pipe= {
	    .sink$a72af214bdd8aa6e=
		&_jc_java_nio_channels_Pipe$method$sink$a72af214bdd8aa6e,
	    .source$025193fa1d7529c6=
		&_jc_java_nio_channels_Pipe$method$source$025193fa1d7529c6,
	},
    }
};

==> jc-1.4.5.tar.gz: java/nio/channels/Pipe.c <==
// public abstract class java.nio.channels.Pipe

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 2951d2f8b8defcbd java_nio_channels_Pipe
// @dep_class 8a9bac808797868c java_nio_channels_Pipe__24SinkChannel
// @dep_class 2a71a1103f7cdc8f java_nio_channels_Pipe__24SourceChannel
// @dep_class 7a7cc23db1b62549 java_nio_channels_spi_SelectorProvider

// header file dependencies
// @dep_header java_io_IOException
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_nio_channels_Pipe
// @dep_header java_nio_channels_Pipe__24SinkChannel
// @dep_header java_nio_channels_Pipe__24SourceChannel
// @dep_header java_nio_channels_spi_SelectorProvider

#include "jc_defs.h"

#include "java/io/IOException.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/nio/channels/Pipe.h"
#include "java/nio/channels/Pipe__24SinkChannel.h"
#include "java/nio/channels/Pipe__24SourceChannel.h"
#include "java/nio/channels/spi/SelectorProvider.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static java.nio.channels.Pipe open() throws java.io.IOException
//

static _jc_linenum _jc_java_nio_channels_Pipe$linenum_table$open$c01270b8d8c80227[];

static const unsigned char _jc_java_nio_channels_Pipe$param_ptypes$open$c01270b8d8c80227[] = { 
_JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_nio_channels_Pipe$exceptions$open$c01270b8d8c80227[] = {
	&_jc_java_io_IOException$type
};

_jc_method _jc_java_nio_channels_Pipe$method_info$open$c01270b8d8c80227 = {
	.name=			"open",
	.signature=		"()Ljava/nio/channels/Pipe;",
	.class=			&_jc_java_nio_channels_Pipe$type,
	.return_type=		&_jc_java_nio_channels_Pipe$type,
	.param_ptypes=		&_jc_java_nio_channels_Pipe$param_ptypes$open$c01270b8d8c80227,
	.signature_hash=	_JC_JLONG(0xc01270b8d8c80227),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_java_nio_channels_Pipe$method$open$c01270b8d8c80227,
	.num_parameters=	0,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_nio_channels_Pipe$exceptions$open$c01270b8d8c80227,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_nio_channels_Pipe$linenum_table$open$c01270b8d8c80227
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_nio_channels_Pipe, open$c01270b8d8c80227);

_jc_java_nio_channels_Pipe$object * _JC_JCNI_ATTR
_jc_java_nio_channels_Pipe$method$open$c01270b8d8c80227(_jc_env *const env)
{
	struct _jc_java_nio_channels_spi_SelectorProvider$object *r0;
	struct _jc_java_nio_channels_Pipe$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	_JC_LINE_NUMBER(109);				// 0
	r0 = _JC_INVOKE_STATIC(env, java_nio_channels_spi_SelectorProvider, provider$f1e7ffe0eaeee1b8, 0);
	r1 = _JC_INVOKE_VIRTUAL(env, java_nio_channels_spi_SelectorProvider, openPipe$a14c1306bc23b331, r0);
	return r1;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>()
//

static _jc_linenum _jc_java_nio_channels_Pipe$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_nio_channels_Pipe$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_nio_channels_Pipe$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_nio_channels_Pipe$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_nio_channels_Pipe$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_java_nio_channels_Pipe$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_nio_channels_Pipe$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_nio_channels_Pipe, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_nio_channels_Pipe$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_nio_channels_Pipe$object *this)
{
	struct _jc_java_nio_channels_Pipe$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(100);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract java.nio.channels.Pipe$SinkChannel sink()
//

static const unsigned char _jc_java_nio_channels_Pipe$param_ptypes$sink$a72af214bdd8aa6e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_nio_channels_Pipe$method_info$sink$a72af214bdd8aa6e = {
	.name=			"sink",
	.signature=		"()Ljava/nio/channels/Pipe$SinkChannel;",
	.class=			&_jc_java_nio_channels_Pipe$type,
	.return_type=		&_jc_java_nio_channels_Pipe__24SinkChannel$type,
	.param_ptypes=		&_jc_java_nio_channels_Pipe$param_ptypes$sink$a72af214bdd8aa6e,
	.signature_hash=	_JC_JLONG(0xa72af214bdd8aa6e),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_nio_channels_Pipe$method$sink$a72af214bdd8aa6e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_nio_channels_Pipe$vtable, java_nio_channels_Pipe.sink$a72af214bdd8aa6e) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_nio_channels_Pipe__24SinkChannel$object * _JC_JCNI_ATTR
_jc_java_nio_channels_Pipe$method$sink$a72af214bdd8aa6e(_jc_env *const env, _jc_java_nio_channels_Pipe$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_nio_channels_Pipe$method_info$sink$a72af214bdd8aa6e);
}

//
// public abstract java.nio.channels.Pipe$SourceChannel source()
//

static const unsigned char _jc_java_nio_channels_Pipe$param_ptypes$source$025193fa1d7529c6[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_nio_channels_Pipe$method_info$source$025193fa1d7529c6 = {
	.name=			"source",
	.signature=		"()Ljava/nio/channels/Pipe$SourceChannel;",
	.class=			&_jc_java_nio_channels_Pipe$type,
	.return_type=		&_jc_java_nio_channels_Pipe__24SourceChannel$type,
	.param_ptypes=		&_jc_java_nio_channels_Pipe$param_ptypes$source$025193fa1d7529c6,
	.signature_hash=	_JC_JLONG(0x25193fa1d7529c6),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_nio_channels_Pipe$method$source$025193fa1d7529c6,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_nio_channels_Pipe$vtable, java_nio_channels_Pipe.source$025193fa1d7529c6) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_nio_channels_Pipe__24SourceChannel$object * _JC_JCNI_ATTR
_jc_java_nio_channels_Pipe$method$source$025193fa1d7529c6(_jc_env *const env, _jc_java_nio_channels_Pipe$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_nio_channels_Pipe$method_info$source$025193fa1d7529c6);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_nio_channels_Pipe$methods[] = {
	&_jc_java_nio_channels_Pipe$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_nio_channels_Pipe$method_info$open$c01270b8d8c80227,
	&_jc_java_nio_channels_Pipe$method_info$sink$a72af214bdd8aa6e,
	&_jc_java_nio_channels_Pipe$method_info$source$025193fa1d7529c6
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_nio_channels_Pipe$instanceof_hash_bucket_61[] = {
	&_jc_java_nio_channels_Pipe$type,
	_JC_NULL
};
static _jc_type *const _jc_java_nio_channels_Pipe$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_nio_channels_Pipe$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[61]=	_jc_java_nio_channels_Pipe$instanceof_hash_bucket_61,
	[101]=	_jc_java_nio_channels_Pipe$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_nio_channels_Pipe$class_depends[] = {
	{ "java/io/IOException",	_JC_JLONG(0x4e0a56550c69d57c) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/nio/channels/Pipe$SinkChannel",	_JC_JLONG(0x8a9bac808797868c) },
	{ "java/nio/channels/Pipe$SourceChannel",	_JC_JLONG(0x2a71a1103f7cdc8f) },
	{ "java/nio/channels/spi/SelectorProvider",	_JC_JLONG(0x7a7cc23db1b62549) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Inner class list
static _jc_inner_class _jc_java_nio_channels_Pipe$inner_classes[] = {
	{ &_jc_java_nio_channels_Pipe__24SourceChannel$type, _JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_ABSTRACT },
	{ &_jc_java_nio_channels_Pipe__24SinkChannel$type, _JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_ABSTRACT },
};

// Class info
_jc_java_nio_channels_Pipe$vtype _jc_java_nio_channels_Pipe$type = {
    .type= {
	.name=			"java/nio/channels/Pipe",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x2951d2f8b8defcbd),
		.source_file=		"Pipe.java",
		.instance_size=		sizeof(_jc_java_nio_channels_Pipe$refs) + sizeof(_jc_java_nio_channels_Pipe$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_nio_channels_Pipe$methods) / sizeof(*_jc_java_nio_channels_Pipe$methods),
		.methods=		_jc_java_nio_channels_Pipe$methods,
		.instanceof_hash_table=	_jc_java_nio_channels_Pipe$instanceof_hash_table,
		.num_inner_classes=	2,
		.inner_classes=		_jc_java_nio_channels_Pipe$inner_classes,
		.num_class_depends=		sizeof(_jc_java_nio_channels_Pipe$class_depends) / sizeof(*_jc_java_nio_channels_Pipe$class_depends),
		.class_depends=		_jc_java_nio_channels_Pipe$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_nio_channels_Pipe= {
	    .sink$a72af214bdd8aa6e=
		&_jc_java_nio_channels_Pipe$method$sink$a72af214bdd8aa6e,
	    .source$025193fa1d7529c6=
		&_jc_java_nio_channels_Pipe$method$source$025193fa1d7529c6,
	},
    }
};
